==> apache-camel-2.25.4-src.zip: apache-camel-2.25.4/components/camel-servicenow/camel-servicenow-component/src/main/java/org/apache/camel/component/servicenow/AbstractServiceNowProducer.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.servicenow;

import org.apache.camel.impl.HeaderSelectorProducer;

public abstract class AbstractServiceNowProducer extends HeaderSelectorProducer implements ServiceNowProducer {
    private final ServiceNowRelease release;
    private final ServiceNowEndpoint endpoint;

    public AbstractServiceNowProducer(ServiceNowEndpoint endpoint, ServiceNowRelease release) {
        super(endpoint, ServiceNowConstants.RESOURCE, endpoint.getConfiguration().getResource());

        this.release = release;
        this.endpoint = endpoint;
    }

    @Override
    public ServiceNowRelease getRelease() {
        return release;
    }

    protected final ServiceNowConfiguration getConfiguration() {
        return endpoint.getConfiguration();
    }
}

==> apache-camel-4.17.0-src.zip: apache-camel-4.17.0/components/camel-servicenow/camel-servicenow-component/src/main/java/org/apache/camel/component/servicenow/AbstractServiceNowProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.servicenow;

import org.apache.camel.support.HeaderSelectorProducer;

public abstract class AbstractServiceNowProducer extends HeaderSelectorProducer implements ServiceNowProducer {
    private final ServiceNowRelease release;
    private final ServiceNowEndpoint endpoint;

    public AbstractServiceNowProducer(ServiceNowEndpoint endpoint, ServiceNowRelease release) {
        super(endpoint, ServiceNowConstants.RESOURCE, endpoint.getConfiguration().getResource());

        this.release = release;
        this.endpoint = endpoint;
    }

    @Override
    public ServiceNowRelease getRelease() {
        return release;
    }

    protected final ServiceNowConfiguration getConfiguration() {
        return endpoint.getConfiguration();
    }
}
